## S3 method for class 'rq':
tidy(x, se.type = "rank", conf.int = TRUE, conf.level = 0.95,
alpha = 1 - conf.level, ...)## S3 method for class 'rqs':
tidy(x, se.type = "rank", conf.int = TRUE,
conf.level = 0.95, alpha = 1 - conf.level, ...)
## S3 method for class 'nlrq':
tidy(x, conf.int = FALSE, conf.level = 0.95, ...)
## S3 method for class 'rq':
glance(x, ...)
## S3 method for class 'nlrq':
glance(x, ...)
## S3 method for class 'rq':
augment(x, data = model.frame(x), newdata, ...)
## S3 method for class 'rqs':
augment(x, data = model.frame(x), newdata, ...)
## S3 method for class 'nlrq':
augment(x, data = NULL, newdata = NULL, ...)
rq or nlrqsummary.rqse.type = "rank"se.type = "rank"; defaults to the same
as conf.level although the specification is invertedsummary.rqtidy.rq returns a data frame with one row for each coefficient.
The columns depend upon the confidence interval method selected.
tidy.rqs returns a data frame with one row for each coefficient at
each quantile that was estimated. The columns depend upon the confidence interval
method selected.
tidy.nlrq returns one row for each coefficient in the model,
with five columns:
glance.rq returns one row for each quantile (tau)
with the columns:glance.rq returns one row for each quantile (tau)
with the columns:augment.rq returns a row for each original observation
with the following columns added:predict.rq via ...
a confidence interval is also calculated on the fitted values resulting in
columns:predict.rq for details on additional arguments to specify
confidence intervals. predict.rq does not provide confidence intervals
when newdata is provided.augment.rqs returns a row for each original observation
and each estimated quantile (tau) with the following columns added:
predict.rqs does not return confidence interval estimates.augment.rqs returns a row for each original observation
with the following columns added:
se.type != "rank" and conf.int = TRUE confidence
intervals are calculated by summary.rq. Otherwise they are standard t
based intervals.This simply calls augment.nls on the "nlrq" object.